==> ember-headlessui-0.11.0.tgz: package/CHANGELOG.md <==

## v0.11.0 (2021-12-18)

#### :rocket: Enhancement
* [#118](https://github.com/GavinJoyce/ember-headlessui/pull/118) Support Ember 4 ([@NullVoxPopuli](https://github.com/NullVoxPopuli))
* [#100](https://github.com/GavinJoyce/ember-headlessui/pull/100) Menu: add additional keydown events and tests  ([@roomman](https://github.com/roomman))

#### :house: Internal
* [#112](https://github.com/GavinJoyce/ember-headlessui/pull/112) drop ie11 from dummy app targets ([@GavinJoyce](https://github.com/GavinJoyce))
* [#111](https://github.com/GavinJoyce/ember-headlessui/pull/111) upgrade ember-auto-import ([@GavinJoyce](https://github.com/GavinJoyce))

#### Committers: 3
- Gavin Joyce ([@GavinJoyce](https://github.com/GavinJoyce))
- Simon Zimmerman ([@roomman](https://github.com/roomman))
- [@NullVoxPopuli](https://github.com/NullVoxPopuli)

## v0.10.3 (2021-11-12)

## v0.10.2 (2021-10-11)

#### :bug: Bug Fix

- [#104](https://github.com/GavinJoyce/ember-headlessui/pull/104) ✅ transition with menu composition ([@far-fetched](https://github.com/far-fetched))

#### :memo: Documentation

- [#102](https://github.com/GavinJoyce/ember-headlessui/pull/102) remove unused `@key` argument ([@GavinJoyce](https://github.com/GavinJoyce))

#### Committers: 3

- Gavin Joyce ([@GavinJoyce](https://github.com/GavinJoyce))
- Mateus Alexandre ([@mateusalexandre](https://github.com/mateusalexandre))
- Piotr ([@far-fetched](https://github.com/far-fetched))

## v0.10.0 (2021-10-05)

#### :rocket: Enhancement

- [#91](https://github.com/GavinJoyce/ember-headlessui/pull/91) Use `tag-name-is-component` helper to remove need for `Menu::ItemElement` backing class ([@GavinJoyce](https://github.com/GavinJoyce))

#### :bug: Bug Fix

- [#85](https://github.com/GavinJoyce/ember-headlessui/pull/85) Menu: preventing default key event behaviours + adding menu tests ([@roomman](https://github.com/roomman))
- [#98](https://github.com/GavinJoyce/ember-headlessui/pull/98) ➖ Remove ember focus trap addon ([@far-fetched](https://github.com/far-fetched))
- [#79](https://github.com/GavinJoyce/ember-headlessui/pull/79) Fix build error for consuming apps, caused by (set) helper ([@roomman](https://github.com/roomman))
- [#84](https://github.com/GavinJoyce/ember-headlessui/pull/84) 🐛 <Transition> pass appear param to child transition ([@far-fetched](https://github.com/far-fetched))

#### :memo: Documentation

- [#83](https://github.com/GavinJoyce/ember-headlessui/pull/83) ✨ Feature: listbox transitions ([@dmcnamara-eng](https://github.com/dmcnamara-eng))

#### :house: Internal

- [#89](https://github.com/GavinJoyce/ember-headlessui/pull/89) Add typescript ([@NullVoxPopuli](https://github.com/NullVoxPopuli))
- [#90](https://github.com/GavinJoyce/ember-headlessui/pull/90) Prepare for typescript ([@NullVoxPopuli](https://github.com/NullVoxPopuli))

#### Committers: 5

- David McNamara ([@dmcnamara-eng](https://github.com/dmcnamara-eng))
- Gavin Joyce ([@GavinJoyce](https://github.com/GavinJoyce))
- Piotr ([@far-fetched](https://github.com/far-fetched))
- Simon Zimmerman ([@roomman](https://github.com/roomman))
- [@NullVoxPopuli](https://github.com/NullVoxPopuli)

## v0.9.0 (2021-09-03)

#### :rocket: Enhancement

- [#76](https://github.com/GavinJoyce/ember-headlessui/pull/76) ✨ Implement `<Listbox />` component ([@dmcnamara-eng](https://github.com/dmcnamara-eng))

#### Committers: 1

- David McNamara ([@dmcnamara-eng](https://github.com/dmcnamara-eng))

## v0.8.0 (2021-09-02)

#### :rocket: Enhancement

- [#68](https://github.com/GavinJoyce/ember-headlessui/pull/68) Implement `Transition` Component ([@alexlafroscia](https://github.com/alexlafroscia))

#### Committers: 1

- Alex LaFroscia ([@alexlafroscia](https://github.com/alexlafroscia))

## v0.7.0 (2021-08-30)

#### :rocket: Enhancement

- [#75](https://github.com/GavinJoyce/ember-headlessui/pull/75) feat(menu): yield actions to open/close menu ([@alexlafroscia](https://github.com/alexlafroscia))

#### Committers: 1

- Alex LaFroscia ([@alexlafroscia](https://github.com/alexlafroscia))

## v0.6.0 (2021-08-30)

##### :rocket: Enhancement

- [#74](https://github.com/GavinJoyce/ember-headlessui/pull/74) feat(menu): allow item element to be a component ([@alexlafroscia](https://github.com/alexlafroscia))

## v0.5.0 (2021-08-11)

#### :boom: Breaking Change

- [#58](https://github.com/GavinJoyce/ember-headlessui/pull/58) `Menu` Component Improvements ([@alexlafroscia](https://github.com/alexlafroscia))

#### :rocket: Enhancement

- [#64](https://github.com/GavinJoyce/ember-headlessui/pull/64) ✨ `<Dialog/>` feature/support for nesting dialogs ([@far-fetched](https://github.com/far-fetched))
- [#59](https://github.com/GavinJoyce/ember-headlessui/pull/59) Set `aria` relationship between Menu and Menu Items ([@alexlafroscia](https://github.com/alexlafroscia))
- [#57](https://github.com/GavinJoyce/ember-headlessui/pull/57) feat(menu): implement search functionality ([@alexlafroscia](https://github.com/alexlafroscia))

#### :memo: Documentation

- [#60](https://github.com/GavinJoyce/ember-headlessui/pull/60) Generate `404` page for Docs site ([@alexlafroscia](https://github.com/alexlafroscia))

#### :house: Internal

- [#66](https://github.com/GavinJoyce/ember-headlessui/pull/66) Configure Project to use Volta ([@alexlafroscia](https://github.com/alexlafroscia))
- [#67](https://github.com/GavinJoyce/ember-headlessui/pull/67) Lint Files on Commit ([@alexlafroscia](https://github.com/alexlafroscia))
- [#56](https://github.com/GavinJoyce/ember-headlessui/pull/56) Format `.hbs` files with Prettier ([@alexlafroscia](https://github.com/alexlafroscia))

#### Committers: 2

- Alex LaFroscia ([@alexlafroscia](https://github.com/alexlafroscia))
- Piotr Panek ([@far-fetched](https://github.com/far-fetched))

==> ember-headlessui-0.11.1.tgz: package/CHANGELOG.md <==

## v0.11.1 (2022-01-09)

#### :bug: Bug Fix
* [#127](https://github.com/GavinJoyce/ember-headlessui/pull/127) Move ember-modifier to dependencies ([@NullVoxPopuli](https://github.com/NullVoxPopuli))
* [#121](https://github.com/GavinJoyce/ember-headlessui/pull/121) Fix `it should add a scroll lock to the html tag` test ([@bertdeblock](https://github.com/bertdeblock))

#### :house: Internal
* [#122](https://github.com/GavinJoyce/ember-headlessui/pull/122), [#123](https://github.com/GavinJoyce/ember-headlessui/pull/123), [#124](https://github.com/GavinJoyce/ember-headlessui/pull/124) Enable skipped transition tests again ([@bertdeblock](https://github.com/bertdeblock))

#### Committers: 2
- Bert De Block ([@bertdeblock](https://github.com/bertdeblock))
- [@NullVoxPopuli](https://github.com/NullVoxPopuli)


## v0.11.0 (2021-12-18)

#### :rocket: Enhancement

- [#118](https://github.com/GavinJoyce/ember-headlessui/pull/118) Support Ember 4 ([@NullVoxPopuli](https://github.com/NullVoxPopuli))
- [#100](https://github.com/GavinJoyce/ember-headlessui/pull/100) Menu: add additional keydown events and tests ([@roomman](https://github.com/roomman))

#### :house: Internal

- [#112](https://github.com/GavinJoyce/ember-headlessui/pull/112) drop ie11 from dummy app targets ([@GavinJoyce](https://github.com/GavinJoyce))
- [#111](https://github.com/GavinJoyce/ember-headlessui/pull/111) upgrade ember-auto-import ([@GavinJoyce](https://github.com/GavinJoyce))

#### Committers: 3

- Gavin Joyce ([@GavinJoyce](https://github.com/GavinJoyce))
- Simon Zimmerman ([@roomman](https://github.com/roomman))
- [@NullVoxPopuli](https://github.com/NullVoxPopuli)

## v0.10.3 (2021-11-12)

## v0.10.2 (2021-10-11)

#### :bug: Bug Fix

- [#104](https://github.com/GavinJoyce/ember-headlessui/pull/104) ✅ transition with menu composition ([@far-fetched](https://github.com/far-fetched))

#### :memo: Documentation

- [#102](https://github.com/GavinJoyce/ember-headlessui/pull/102) remove unused `@key` argument ([@GavinJoyce](https://github.com/GavinJoyce))

#### Committers: 3

- Gavin Joyce ([@GavinJoyce](https://github.com/GavinJoyce))
- Mateus Alexandre ([@mateusalexandre](https://github.com/mateusalexandre))
- Piotr ([@far-fetched](https://github.com/far-fetched))

## v0.10.0 (2021-10-05)

#### :rocket: Enhancement

- [#91](https://github.com/GavinJoyce/ember-headlessui/pull/91) Use `tag-name-is-component` helper to remove need for `Menu::ItemElement` backing class ([@GavinJoyce](https://github.com/GavinJoyce))

#### :bug: Bug Fix

- [#85](https://github.com/GavinJoyce/ember-headlessui/pull/85) Menu: preventing default key event behaviours + adding menu tests ([@roomman](https://github.com/roomman))
- [#98](https://github.com/GavinJoyce/ember-headlessui/pull/98) ➖ Remove ember focus trap addon ([@far-fetched](https://github.com/far-fetched))
- [#79](https://github.com/GavinJoyce/ember-headlessui/pull/79) Fix build error for consuming apps, caused by (set) helper ([@roomman](https://github.com/roomman))
- [#84](https://github.com/GavinJoyce/ember-headlessui/pull/84) 🐛 <Transition> pass appear param to child transition ([@far-fetched](https://github.com/far-fetched))

#### :memo: Documentation

- [#83](https://github.com/GavinJoyce/ember-headlessui/pull/83) ✨ Feature: listbox transitions ([@dmcnamara-eng](https://github.com/dmcnamara-eng))

#### :house: Internal

- [#89](https://github.com/GavinJoyce/ember-headlessui/pull/89) Add typescript ([@NullVoxPopuli](https://github.com/NullVoxPopuli))
- [#90](https://github.com/GavinJoyce/ember-headlessui/pull/90) Prepare for typescript ([@NullVoxPopuli](https://github.com/NullVoxPopuli))

#### Committers: 5

- David McNamara ([@dmcnamara-eng](https://github.com/dmcnamara-eng))
- Gavin Joyce ([@GavinJoyce](https://github.com/GavinJoyce))
- Piotr ([@far-fetched](https://github.com/far-fetched))
- Simon Zimmerman ([@roomman](https://github.com/roomman))
- [@NullVoxPopuli](https://github.com/NullVoxPopuli)

## v0.9.0 (2021-09-03)

#### :rocket: Enhancement

- [#76](https://github.com/GavinJoyce/ember-headlessui/pull/76) ✨ Implement `<Listbox />` component ([@dmcnamara-eng](https://github.com/dmcnamara-eng))

#### Committers: 1

- David McNamara ([@dmcnamara-eng](https://github.com/dmcnamara-eng))

## v0.8.0 (2021-09-02)

#### :rocket: Enhancement

- [#68](https://github.com/GavinJoyce/ember-headlessui/pull/68) Implement `Transition` Component ([@alexlafroscia](https://github.com/alexlafroscia))

#### Committers: 1

- Alex LaFroscia ([@alexlafroscia](https://github.com/alexlafroscia))

## v0.7.0 (2021-08-30)

#### :rocket: Enhancement

- [#75](https://github.com/GavinJoyce/ember-headlessui/pull/75) feat(menu): yield actions to open/close menu ([@alexlafroscia](https://github.com/alexlafroscia))

#### Committers: 1

- Alex LaFroscia ([@alexlafroscia](https://github.com/alexlafroscia))

## v0.6.0 (2021-08-30)

##### :rocket: Enhancement

- [#74](https://github.com/GavinJoyce/ember-headlessui/pull/74) feat(menu): allow item element to be a component ([@alexlafroscia](https://github.com/alexlafroscia))

## v0.5.0 (2021-08-11)

#### :boom: Breaking Change

- [#58](https://github.com/GavinJoyce/ember-headlessui/pull/58) `Menu` Component Improvements ([@alexlafroscia](https://github.com/alexlafroscia))

#### :rocket: Enhancement

- [#64](https://github.com/GavinJoyce/ember-headlessui/pull/64) ✨ `<Dialog/>` feature/support for nesting dialogs ([@far-fetched](https://github.com/far-fetched))
- [#59](https://github.com/GavinJoyce/ember-headlessui/pull/59) Set `aria` relationship between Menu and Menu Items ([@alexlafroscia](https://github.com/alexlafroscia))
- [#57](https://github.com/GavinJoyce/ember-headlessui/pull/57) feat(menu): implement search functionality ([@alexlafroscia](https://github.com/alexlafroscia))

#### :memo: Documentation

- [#60](https://github.com/GavinJoyce/ember-headlessui/pull/60) Generate `404` page for Docs site ([@alexlafroscia](https://github.com/alexlafroscia))

#### :house: Internal

- [#66](https://github.com/GavinJoyce/ember-headlessui/pull/66) Configure Project to use Volta ([@alexlafroscia](https://github.com/alexlafroscia))
- [#67](https://github.com/GavinJoyce/ember-headlessui/pull/67) Lint Files on Commit ([@alexlafroscia](https://github.com/alexlafroscia))
- [#56](https://github.com/GavinJoyce/ember-headlessui/pull/56) Format `.hbs` files with Prettier ([@alexlafroscia](https://github.com/alexlafroscia))

#### Committers: 2

- Alex LaFroscia ([@alexlafroscia](https://github.com/alexlafroscia))
- Piotr Panek ([@far-fetched](https://github.com/far-fetched))
